# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['iso_4217_currency_codes', 'iso_4217_currency_codes.assets']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'iso-4217-currency-codes',
    'version': '23.4.23',
    'description': 'All currency codes in one package',
    'long_description': '## Description\nComprehensive Python package for managing currency codes across different types of assets. Having all the currency codes in one package can simplify the development process for applications that involve multiple currencies and assets. This package could also help to ensure consistency and accuracy in managing currency codes across different parts of an application  \nThe package provides currency codes for different types of assets. Such as \n- fiat (US dollar, UAE Dirham, ...)\n- crypto (Bitcoin, Solana, ...)\n- commodity (Palladium, Gold, ...)\n- others (WIR Franc, CFP Franc, ...) \n\n## Sources\n - [Coinmarketcap website](https://coinmarketcap.com) for crypto\n - [ISO\'s website](https://www.iso.org/iso-4217-currency-codes.html) for rest\n\n## Installation\nInstall the package with the following command:\n```shell\npip install iso_4217_currency_codes\n```\n\n## How to use the package?\n### Get a currency info by a currency code\nYou can get any currency info using the snippet below\n```python\nfrom iso_4217_currency_codes import get_currency_by_code, Currency\n\ncurrency_code: str = "EUR"\ncurrency: Currency = get_currency_by_code(currency_code)\n```\nif the package doesn\'t know a currency code you can raise a PR to extend the knowledge base but for now the `CurrencyNotFoundError` will be raised.\n\n```python\nfrom iso_4217_currency_codes import get_currency_by_code, CurrencyNotFoundError\n\n# non-existent currency code\ncurrency_code: str = "EUR000"\ntry:\n    get_currency_by_code(currency_code)\nexcept CurrencyNotFoundError:\n    print("Non-existent code have been used")\n```\n\n\n### Get a currency info by a currency numeric code\nTo get a currency info you can also use the numeric code like in the example below\n```python\nfrom iso_4217_currency_codes import get_currency_by_numeric_code, Currency\n\n# Euro has 978 numeric code\ncurrency_numeric_code: str = "978"\ncurrency: Currency = get_currency_by_numeric_code(currency_numeric_code)\n```\nif the package doesn\'t know a currency numeric code you can raise a PR to extend the knowledge base but for now the `CurrencyNotFoundError` will be raised.\n\n```python\nfrom iso_4217_currency_codes import get_currency_by_numeric_code, CurrencyNotFoundError\n\n# non-existent currency numeric code\ncurrency_numeric_code: str = "00000000"\ntry:\n    get_currency_by_numeric_code(currency_numeric_code)\nexcept CurrencyNotFoundError:\n    print("Non-existent numeric code have been used")\n```\n\n\n### Get the list of all currencies\nIf you want to get information about all currencies, you can use `get_all_currencies` function\n```python\nfrom iso_4217_currency_codes import get_all_currencies, Currency\n\ncurrencies: list[Currency] = get_all_currencies()\n```\n\n### Get the list of fiat currencies\nIf you want to get information only about fiat currencies, you can use `get_fiat_currencies` function\n```python\nfrom iso_4217_currency_codes import get_fiat_currencies, Currency\n\nfiat_currencies: list[Currency] = get_fiat_currencies()\n```\n\n### Get the list of crypto currencies\nIf you want to get information only about crypto currencies, you can use `get_crypto_currencies` function\n```python\nfrom iso_4217_currency_codes import get_crypto_currencies, Currency\n\ncrypto_currencies: list[Currency] = get_crypto_currencies()\n```\n\n### Get the list of commodity currencies\nIf you want to get information only about commodity currencies, you can use `get_commodity_currencies` function\n```python\nfrom iso_4217_currency_codes import get_commodity_currencies, Currency\n\ncommodity_currencies: list[Currency] = get_commodity_currencies()\n```\n\n### Get the list of other currencies\nIf you want to get information only about other currencies, you can use `get_other_currencies` function\n```python\nfrom iso_4217_currency_codes import get_other_currencies, Currency\n\nother_currencies: list[Currency] = get_other_currencies()\n```\n',
    'author': 'Artem Kuchumov',
    'author_email': 'duketemon@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/duketemon/iso-4217_currency-codes',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
